==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/bg.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'bg', {
	acccessKey: 'Ключ за достъп',
	advanced: 'Разширено',
	advisoryContentType: 'Препоръчителен тип на съдържанието',
	advisoryTitle: 'Препоръчително заглавие',
	anchor: {
		toolbar: 'Котва',
		menu: 'Промяна на котва',
		title: 'Настройки на котва',
		name: 'Име на котва',
		errorName: 'Моля въведете име на котвата',
		remove: 'Премахване на котва'
	},
	anchorId: 'По ID на елемент',
	anchorName: 'По име на котва',
	charset: 'Тип на свързания ресурс',
	cssClasses: 'Класове за CSS',
	emailAddress: 'E-mail aдрес',
	emailBody: 'Съдържание',
	emailSubject: 'Тема',
	id: 'ID',
	info: 'Инфо за връзката',
	langCode: 'Код за езика',
	langDir: 'Посока на езика',
	langDirLTR: 'Ляво на Дясно (ЛнД)',
	langDirRTL: 'Дясно на Ляво (ДнЛ)',
	menu: 'Промяна на връзка',
	name: 'Име',
	noAnchors: '(Няма котви в текущия документ)',
	noEmail: 'Моля въведете e-mail aдрес',
	noUrl: 'Моля въведете URL адреса',
	other: '<друго>',
	popupDependent: 'Зависимост (Netscape)',
	popupFeatures: 'Функции на изкачащ прозорец',
	popupFullScreen: 'Цял екран (IE)',
	popupLeft: 'Лява позиция',
	popupLocationBar: 'Лента с локацията',
	popupMenuBar: 'Лента за меню',
	popupResizable: 'Оразмеряем',
	popupScrollBars: 'Скролери',
	popupStatusBar: 'Статусна лента',
	popupToolbar: 'Лента с инструменти',
	popupTop: 'Горна позиция',
	rel: 'Връзка',
	selectAnchor: 'Изберете котва',
	styles: 'Стил',
	tabIndex: 'Ред на достъп',
	target: 'Цел',
	targetFrame: '<frame>',
	targetFrameName: 'Име на целевият прозорец',
	targetPopup: '<изкачащ прозорец>',
	targetPopupName: 'Име на изкачащ прозорец',
	title: 'Връзка',
	toAnchor: 'Връзка към котва в текста',
	toEmail: 'E-mail',
	toUrl: 'Уеб адрес',
	toolbar: 'Връзка',
	type: 'Тип на връзката',
	unlink: 'Премахни връзката',
	upload: 'Качване'
} );

==> ckeditor_4.10.0+dfsg.orig.tar.xz: ckeditor-dev-4.10.0/plugins/link/lang/bg.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'bg', {
	acccessKey: 'Клавиш за достъп',
	advanced: 'Разширено',
	advisoryContentType: 'Тип на съдържанието',
	advisoryTitle: 'Заглавие',
	anchor: {
		toolbar: 'Котва',
		menu: 'Промяна на котва',
		title: 'Настройки на котва',
		name: 'Име на котва',
		errorName: 'Моля въведете име на котвата',
		remove: 'Премахване на котва'
	},
	anchorId: 'По ID на елемент',
	anchorName: 'По име на котва',
	charset: 'Езиков код на свързания ресурс',
	cssClasses: 'CSS класове',
	download: 'Укажи изтегляне',
	displayText: 'Текст за показване',
	emailAddress: 'Имейл aдрес',
	emailBody: 'Съдържание',
	emailSubject: 'Тема',
	id: 'Id',
	info: 'Връзка',
	langCode: 'Езиков код',
	langDir: 'Посока на езика',
	langDirLTR: 'От ляво надясно (LTR)',
	langDirRTL: 'От дясно наляво (RTL)',
	menu: 'Промяна на връзка',
	name: 'Име',
	noAnchors: '(Няма котви в текущия документ)',
	noEmail: 'Моля въведете имейл адрес',
	noUrl: 'Моля въведете URL адрес',
	other: '<друго>',
	popupDependent: 'Зависимост (Netscape)',
	popupFeatures: 'Функции на изкачащ прозорец',
	popupFullScreen: 'Цял екран (IE)',
	popupLeft: 'Лява позиция',
	popupLocationBar: 'Лента с локацията',
	popupMenuBar: 'Лента за меню',
	popupResizable: 'Оразмеряем',
	popupScrollBars: 'Ленти за прелистване',
	popupStatusBar: 'Статусна лента',
	popupToolbar: 'Лента с инструменти',
	popupTop: 'Горна позиция',
	rel: 'Свързаност (rel атрибут)',
	selectAnchor: 'Изберете котва',
	styles: 'Стил',
	tabIndex: 'Ред на достъп',
	target: 'Цел',
	targetFrame: '<frame>',
	targetFrameName: 'Име на целевия прозорец',
	targetPopup: '<изкачащ прозорец>',
	targetPopupName: 'Име на изкачащ прозорец',
	title: 'Връзка',
	toAnchor: 'Връзка към котва в текста',
	toEmail: 'Имейл',
	toUrl: 'Уеб адрес',
	toolbar: 'Връзка',
	type: 'Тип на връзката',
	unlink: 'Премахни връзката',
	upload: 'Качване'
} );
